﻿Option Strict On
Imports Coding4Fun.Kinect.KinectService.Common
Imports Coding4Fun.Kinect.KinectService.PhoneClient
Imports System.IO
Imports System.IO.IsolatedStorage
Imports System.Xml.Linq
Imports System.Windows.Threading
Partial Public Class MainPage
    Inherits PhoneApplicationPage

    ' コンストラクター
    Public Sub New()
        InitializeComponent()
    End Sub
    Dim flag As Boolean = False
    Dim _skeletonClient As SkeletonClient
    Dim _colorClient As ColorClient
    Dim nowTime As String = String.Empty
    Dim inTime As String
    Dim myTimer As DispatcherTimer
    Protected Overrides Sub OnNavigatedTo(e As System.Windows.Navigation.NavigationEventArgs)
        myTimer = New DispatcherTimer
        myTimer.Interval = New TimeSpan(1000)

        AddHandler myTimer.Tick, Sub(timerSender As Object, timerArgs As EventArgs)
                                     inTextBlock.Text = DateTime.Now.ToString("yyyy年MM月dd日HH時mm分ss秒")
                                 End Sub
        myTimer.Start()
        Dim storage As IsolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication
        If storage.DirectoryExists("kinect") = False Then
            storage.CreateDirectory("kinect")
        End If
        Dim xmlFilePath As String = Path.Combine("kinect", "FileList.xml")
        If storage.FileExists(xmlFilePath) = True Then
            dataButton.IsEnabled = True
        Else
            dataButton.IsEnabled = False
        End If
        MyBase.OnNavigatedTo(e)
    End Sub

    Private Sub okButton_Click(sender As System.Object, e As System.Windows.RoutedEventArgs) Handles okButton.Click
        Dim myIPAddress As String = addressTextBox.Text

        If myIPAddress = String.Empty Then
            MessageBox.Show("Addressを入力してください。")
            Exit Sub
        Else
            _skeletonClient = New SkeletonClient()
            _colorClient = New ColorClient()

            If Not _colorClient.IsConnected Then
                _colorClient.Connect(myIPAddress, 4530)
            Else
                _colorClient.Disconnect()
            End If
            If Not _skeletonClient.IsConnected Then
                _skeletonClient.Connect(myIPAddress, 4532)
            Else
                _skeletonClient.Disconnect()
            End If
            AddHandler _colorClient.ColorFrameReady, AddressOf client_ColorFrameReady
            AddHandler _skeletonClient.SkeletonFrameReady, AddressOf client_SkeletonFrameReady
        End If

    End Sub

    Private Sub client_ColorFrameReady(ByVal sender As Object, ByVal e As ColorFrameReadyEventArgs)
        If e.ColorFrame.BitmapImage Is Nothing = False Then
            Image1.Source = e.ColorFrame.BitmapImage
        End If
        TextBlock1.Text = flag.ToString
        If flag = True Then
            myTimer.Stop()
            ListBox1.Items.Clear()
            ListBox1.Items.Add(DateTime.Now.ToString("yyyy年MM月dd日HH時mm分ss秒"))
            ListBox1.SelectedIndex = 0

        Else
            DataSave()
            myTimer.Start()
        End If
    End Sub

    Private Sub client_SkeletonFrameReady(ByVal sender As Object, ByVal e As SkeletonFrameReadyEventArgs)
        Dim mySkeleton As Skeleton = (From s In e.SkeletonFrame.Skeletons Where s.TrackingState = SkeletonTrackingState.Tracked Select s).FirstOrDefault()

        If mySkeleton Is Nothing Then
            flag = False
            myTimer.Start()
            Return
        Else
            flag = True
            myTimer.Stop()
        End If
    End Sub


    Private Sub DataSave()

        If ListBox1.Items.Count > 0 Then
            nowTime = ListBox1.SelectedItem.ToString
            inTime = inTextBlock.Text

            Dim xmlStorage As IsolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication
            Dim xmlFilePath As String = Path.Combine("kinect", "FileList.xml")

            If xmlStorage.FileExists(xmlFilePath) = False Then
                Dim xmldoc As XDocument = <?xml version="1.0" encoding="utf-8"?>
                                          <人物記録>
                                              <情報>
                                                  <入時間><%= inTime %></入時間>
                                                  <出時間><%= nowTime %></出時間>
                                              </情報>

                                          </人物記録>
                Using xmlStream As IsolatedStorageFileStream = xmlStorage.CreateFile(xmlFilePath)
                End Using


                If xmlStorage.FileExists(xmlFilePath) = True Then
                    Using xmlwriter As StreamWriter = New StreamWriter(xmlStorage.OpenFile(xmlFilePath, FileMode.Open, FileAccess.Write))
                        xmlwriter.Flush()
                        xmlwriter.Write(xmldoc.ToString)
                    End Using
                    dataButton.IsEnabled = True

                End If
            Else
                Dim xmlStream As IsolatedStorageFileStream = xmlStorage.OpenFile(xmlFilePath, FileMode.Open, FileAccess.Read)
                Using xmlreader As StreamReader = New StreamReader(xmlStream)

                    Dim readXmldoc As String = xmlreader.ReadToEnd
                    Dim doc As XElement = XElement.Parse(readXmldoc)
                    Dim addXml As XElement = <情報>
                                                 <入時間><%= inTime %></入時間>
                                                 <出時間><%= nowTime %></出時間>
                                             </情報>
                    doc.Add(addXml)
                    xmlStream.Close()

                    If xmlStorage.FileExists(xmlFilePath) = True Then
                        Using xmlwriter As StreamWriter = New StreamWriter(xmlStorage.OpenFile(xmlFilePath, FileMode.Open, FileAccess.Write))
                            xmlwriter.Flush()
                            xmlwriter.Write(doc.ToString)
                            dataButton.IsEnabled = True
                        End Using
                    End If
                End Using
            End If
            ListBox1.Items.Clear()
        End If
    End Sub

    Private Sub dataButton_Click(sender As System.Object, e As System.Windows.RoutedEventArgs) Handles dataButton.Click
        RemoveHandler _colorClient.ColorFrameReady, AddressOf client_ColorFrameReady
        RemoveHandler _skeletonClient.SkeletonFrameReady, AddressOf client_SkeletonFrameReady
        _colorClient.Disconnect()
        _skeletonClient.Disconnect()
        NavigationService.Navigate(New Uri("/DataIchiranPage.xaml", UriKind.Relative))
    End Sub
End Class
